# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.crypto_api import CryptoApi


class TestCryptoApi(unittest.TestCase):
    """CryptoApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CryptoApi()

    def tearDown(self) -> None:
        pass

    def test_crypto_certificatekeypairs_create(self) -> None:
        """Test case for crypto_certificatekeypairs_create

        """
        pass

    def test_crypto_certificatekeypairs_destroy(self) -> None:
        """Test case for crypto_certificatekeypairs_destroy

        """
        pass

    def test_crypto_certificatekeypairs_generate_create(self) -> None:
        """Test case for crypto_certificatekeypairs_generate_create

        """
        pass

    def test_crypto_certificatekeypairs_list(self) -> None:
        """Test case for crypto_certificatekeypairs_list

        """
        pass

    def test_crypto_certificatekeypairs_partial_update(self) -> None:
        """Test case for crypto_certificatekeypairs_partial_update

        """
        pass

    def test_crypto_certificatekeypairs_retrieve(self) -> None:
        """Test case for crypto_certificatekeypairs_retrieve

        """
        pass

    def test_crypto_certificatekeypairs_update(self) -> None:
        """Test case for crypto_certificatekeypairs_update

        """
        pass

    def test_crypto_certificatekeypairs_used_by_list(self) -> None:
        """Test case for crypto_certificatekeypairs_used_by_list

        """
        pass

    def test_crypto_certificatekeypairs_view_certificate_retrieve(self) -> None:
        """Test case for crypto_certificatekeypairs_view_certificate_retrieve

        """
        pass

    def test_crypto_certificatekeypairs_view_private_key_retrieve(self) -> None:
        """Test case for crypto_certificatekeypairs_view_private_key_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
